==> tepl-2.99.1.tar.xz: tepl-2.99.1/tepl/tepl.h <==
/*
 * This file is part of Tepl, a text editor library.
 *
 * Copyright 2016, 2017 - Sébastien Wilmet <swilmet@gnome.org>
 *
 * Tepl is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the
 * Free Software Foundation; either version 2.1 of the License, or (at your
 * option) any later version.
 *
 * Tepl is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 * License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, see <http://www.gnu.org/licenses/>.
 */

#ifndef TEPL_H
#define TEPL_H

#define TEPL_H_INSIDE

#include <tepl/tepl-types.h>
#include <tepl/tepl-enum-types.h>

#include <tepl/tepl-action-info.h>
#include <tepl/tepl-action-info-store.h>
#include <tepl/tepl-action-info-central-store.h>
#include <tepl/tepl-action-map.h>
#include <tepl/tepl-application.h>
#include <tepl/tepl-application-window.h>
#include <tepl/tepl-buffer.h>
#include <tepl/tepl-encoding.h>
#include <tepl/tepl-file.h>
#include <tepl/tepl-file-loader.h>
#include <tepl/tepl-file-metadata.h>
#include <tepl/tepl-file-saver.h>
#include <tepl/tepl-fold-region.h>
#include <tepl/tepl-gutter-renderer-folds.h>
#include <tepl/tepl-info-bar.h>
#include <tepl/tepl-iter.h>
#include <tepl/tepl-menu-item.h>
#include <tepl/tepl-menu-shell.h>
#include <tepl/tepl-metadata-manager.h>
#include <tepl/tepl-tab.h>
#include <tepl/tepl-utils.h>
#include <tepl/tepl-view.h>

#undef TEPL_H_INSIDE

#endif /* TEPL_H */

==> tepl-2.99.2.tar.xz: tepl-2.99.2/tepl/tepl.h <==
/*
 * This file is part of Tepl, a text editor library.
 *
 * Copyright 2016, 2017 - Sébastien Wilmet <swilmet@gnome.org>
 *
 * Tepl is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the
 * Free Software Foundation; either version 2.1 of the License, or (at your
 * option) any later version.
 *
 * Tepl is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 * License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, see <http://www.gnu.org/licenses/>.
 */

#ifndef TEPL_H
#define TEPL_H

#define TEPL_H_INSIDE

#include <amtk/amtk.h>

#include <tepl/tepl-types.h>
#include <tepl/tepl-enum-types.h>

#include <tepl/tepl-application.h>
#include <tepl/tepl-application-window.h>
#include <tepl/tepl-buffer.h>
#include <tepl/tepl-encoding.h>
#include <tepl/tepl-file.h>
#include <tepl/tepl-file-loader.h>
#include <tepl/tepl-file-metadata.h>
#include <tepl/tepl-file-saver.h>
#include <tepl/tepl-fold-region.h>
#include <tepl/tepl-gutter-renderer-folds.h>
#include <tepl/tepl-info-bar.h>
#include <tepl/tepl-iter.h>
#include <tepl/tepl-metadata-manager.h>
#include <tepl/tepl-notebook.h>
#include <tepl/tepl-tab.h>
#include <tepl/tepl-tab-group.h>
#include <tepl/tepl-utils.h>
#include <tepl/tepl-view.h>

#undef TEPL_H_INSIDE

#endif /* TEPL_H */
